@@ -19,6 +19,8 @@ from unit.api.api_token_resource import APITokenResource
 from unit.api.authorization_resource import AuthorizationResource
 from unit.api.authorization_request_resource import AuthorizationRequestResource
 from unit.api.account_end_of_day_resource import AccountEndOfDayResource
+from unit.api.checkDeposit_resource import CheckDepositResource
+from unit.api.dispute_resource import DisputeResource
 
 __all__ = ["api", "models", "utils"]
 
@@ -46,3 +48,5 @@ class Unit(object):
         self.authorizations = AuthorizationResource(api_url, token)
         self.authorization_requests = AuthorizationRequestResource(api_url, token)
         self.account_end_of_day = AccountEndOfDayResource(api_url, token)
+        self.checkDeposits = CheckDepositResource(api_url, token)
+        self.disputes = DisputeResource(api_url, token)
